@@ -11,7 +11,7 @@ res1 <- bayes(formula = ~1/(1 + exp(-b *(x - a))),
               ICA.control = list(rseed = 1366))
 
 \dontrun{
-  res1 <- iterate(res1, 500)
+  res1 <- update(res1, 500)
   plot(res1)
 }
 # You can also use your  Fisher information matrix (FIM) if you think it is faster!
@@ -35,12 +35,12 @@ res1 <- bayes(formula = ~1/(1 + exp(-b *(x - a))),
 # with quadrature formula
 \dontrun{
   res1.2 <- bayes(formula = ~1/(1 + exp(-b *(x - a))),
-                predvars = "x", parvars = c("a", "b"),
-                family = binomial(), lx = -3, ux = 3,
-                k =  5, iter = 1, prior = uni,
-                crt_method = "quadrature",
-                ICA.control = list(rseed = 1366))
-  res1.2 <- iterate(res1.2, 500)
+                  predvars = "x", parvars = c("a", "b"),
+                  family = binomial(), lx = -3, ux = 3,
+                  k =  5, iter = 1, prior = uni,
+                  crt.bayes.control = list(method = "quadrature"),
+                  ICA.control = list(rseed = 1366))
+  res1.2 <- update(res1.2, 500)
   plot(res1.2) # not optimal
   # compare it with res1 that was found by automatic integration
   plot(res1)
@@ -50,12 +50,12 @@ res1 <- bayes(formula = ~1/(1 + exp(-b *(x - a))),
                   predvars = "x", parvars = c("a", "b"),
                   family = binomial(), lx = -3, ux = 3,
                   k =  5, iter = 1, prior = uni,
-                  crt_method = "quadrature",
-                  crt.bayes.control = list(quadrature = list(level = 9)),
+                  crt.bayes.control = list(method = "quadrature",
+                                           quadrature = list(level = 9)),
                   ICA.control = list(rseed = 1366))
-  res1.3 <- iterate(res1.3, 500)
+  res1.3 <- update(res1.3, 500)
   plot(res1.3)
-  # by automatic integration (crt_method = "cubature"),
+  # by automatic integration (method = "cubature"),
   #  we did not need to worry about the number of nodes.
 }
 ###############################################
@@ -70,7 +70,7 @@ norm1 <- normal(mu =  c(0, 1),
   res2 <- bayes(formula = ~1/(1 + exp(-b *(x - a))), predvars = "x", parvars = c("a", "b"),
                 family = binomial(), lx = -3, ux = 3, k =  4, iter = 1, prior = norm1,
                 ICA.control = list(rseed = 1366))
-  res2 <- iterate(res2, 500)
+  res2 <- update(res2, 500)
   plot(res2)
 }
 
@@ -87,9 +87,10 @@ norm2 <- normal(mu =  c(0, 1),
                 family = binomial(), lx = -3, ux = 3, k =  4, iter = 1, prior = norm2,
                 ICA.control = list(rseed = 1366))
 
-  res3 <- iterate(res3, 700)
-  plot(res3, sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4),
-                                       optslist = list(maxeval = 3000)))
+  res3 <- update(res3, 700)
+  plot(res3,
+       sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4)),
+       sens.control = list(optslist = list(maxeval = 3000)))
 }
 
 
@@ -103,8 +104,9 @@ skew1 <- skewnormal(xi = c(0, 1),
   res4 <- bayes(formula = ~1/(1 + exp(-b *(x - a))), predvars = "x", parvars = c("a", "b"),
                 family = binomial(), lx = -3, ux = 3, k =  4, iter = 700, prior = skew1,
                 ICA.control = list(rseed = 1366, ncount = 60))
-  plot(res4, sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4),
-                                       optslist = list(maxeval = 3000)))
+  plot(res4,
+       sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4)),
+       sens.control = list(optslist = list(maxeval = 3000)))
 }
 
 
@@ -118,8 +120,9 @@ skew2 <- skewnormal(xi = c(0, 1),
   res5 <- bayes(formula = ~1/(1 + exp(-b *(x - a))), predvars = "x", parvars = c("a", "b"),
                 family = binomial(), lx = -3, ux = 3, k =  4, iter = 700, prior = skew2,
                 ICA.control = list(rseed = 1366, ncount = 60))
-  plot(res5, sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4),
-                                       optslist = list(maxeval = 3000)))
+  plot(res5,
+       sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4)),
+       sens.control = list(optslist = list(maxeval = 3000)))
 }
 
 ###############################################
@@ -155,8 +158,9 @@ ub <- c(8, 15, 130, 9)
                 predvars = c("x"), parvars = c("theta1", "theta2", "theta3", "theta4"),
                 lx = .001, ux = 500, k = 5, iter = 200, prior = uniform(lb, ub),
                 ICA.control = list(rseed = 1366, ncount = 60))
-  plot(res7, sens.bayes.control = list(cubature = list(maxEval = 500, tol = 1e-3),
-                                       optslist = list(maxeval = 500)))
+  plot(res7,
+       sens.bayes.control = list(cubature = list(maxEval = 500, tol = 1e-3)),
+       sens.control = list(optslist = list(maxeval = 500)))
 }
 
 #######################################################################
@@ -171,9 +175,10 @@ myfim <- function(x, w, param)
                 iter = 1, prior = uniform(c(-11, -11), c(11, 11)),
                 ICA.control = list(rseed = 1366))
 
-  res8 <- iterate(res8, 200)
-  plot(res8, sens.bayes.control = list(cubature = list(maxEval = 500, tol = 1e-3),
-                                       optslist = list(maxeval = 500)))
+  res8 <- update(res8, 200)
+  plot(res8,
+       sens.bayes.control = list(cubature = list(maxEval = 500, tol = 1e-3)),
+       sens.control = list(optslist = list(maxeval = 500)))
 }
 
 
@@ -188,8 +193,9 @@ myfim <- function(x, w, param)
   res9 <- bayes(fimfunc = myfim, lx = 0, ux = 1, k = 2,
                 iter = 200, prior = uniform(c(-11, -11), c(11, 11)),
                 ICA.control = list(rseed = 1366))
-  plot(res9, sens.bayes.control = list(cubature = list(maxEval = 100, tol = 1e-3),
-                                       optslist = list(maxeval = 100)))
+  plot(res9,
+       sens.bayes.control = list(cubature = list(maxEval = 100, tol = 1e-3)),
+       sens.control = list(optslist = list(maxeval = 100)))
 }
 
 #################################
@@ -221,7 +227,7 @@ res11 <- bayes(formula = ~a - b * exp(-lambda * t ^h),
                ICA.control = list(rseed = 1366))
 
 \dontrun{
-  res11 <- iterate(res11, 400)
+  res11 <- update(res11, 400)
   plot(res11)
 }
 
@@ -238,25 +244,26 @@ norm4 <- normal(mu = c(1, 1), sigma = matrix(c(.2, 0.1, 0.1, .4), 2, 2),
                  prior = norm4,
                  k = 5, iter = 400,
                  ICA.control = list(rseed = 1366))
-  plot(res12, sens.bayes.control = list(cubature = list(maxEval = 1000, tol = 1e-3),
-                                        optslist = list(maxeval = 1000)))
+  plot(res12,
+       sens.bayes.control = list(cubature = list(maxEval = 1000, tol = 1e-3)),
+       sens.control = list(optslist = list(maxeval = 1000)))
   ## or we can use the quadrature formula to plot the derivative function
-  plot(res12,sens_method = "quadrature",
-       sens.bayes.control = list(optslist = list(maxeval = 1000)))
+  plot(res12,
+       sens.bayes.control = list(method = "quadrature"),
+       sens.control = list(optslist = list(maxeval = 1000)))
 
 }
 
 #################################
 # Exponential model: Uniform prior
 #################################
+\dontrun{
 res13 <- bayes(formula = ~a + exp(-b*x), predvars = "x",
                parvars = c("a = 1", "b"),
                lx = 0.0001, ux = 1,
                prior = uniform(lower = 1, upper = 20),
-               iter = 1, k = 3,
+               iter = 300, k = 3,
                ICA.control= list(rseed = 100))
-\dontrun{
-  res13 <- iterate(res13, 300)
   plot(res13)
 }
 
@@ -271,7 +278,7 @@ uni1 <- uniform(lower = c(-.3, 6, .5), upper = c(.3, 8, 1))
   res14 <- bayes(formula = ~1/(1 + exp(-b *(x - a)))^s, predvars = "x",
                  parvars = c("a", "b", "s"),
                  lx = -1, ux = 1, prior = uni1, k = 5, iter = 1)
-  res14 <- iterate(res14, 300)
+  res14 <- update(res14, 300)
   plot(res14)
 }
 
@@ -288,28 +295,29 @@ myformula1 <- ~beta0+beta1*x1+beta2*x2+beta3*x1^2+beta4*x2^2+beta5*x1*x2
                  lx = rep(0, 2), ux = rep(1, 2),
                  prior = uniform(lower = lb, upper = ub),
                  k = 7,iter = 1, ICA.control = list(rseed = 1366))
-  res14 <- iterate(res14, 500)
-  plot(res14, sens.bayes.control = list(cubature = list(maxEval = 5000, tol = 1e-4),
-                                        optslist = list(maxeval = 3000)))
+  res14 <- update(res14, 500)
+  plot(res14,
+       sens.bayes.control = list(cubature = list(maxEval = 5000, tol = 1e-4)),
+       sens.control = list(optslist = list(maxeval = 3000)))
 }
 
 #################################
 # Three parameter logistic model
 #################################
-
+\dontrun{
 sigma1 <- matrix(-0.1, nrow = 3, ncol = 3)
 diag(sigma1) <- c(.5, .4, .1)
 norm5 <- normal(mu =  c(0, 1, .2), sigma = sigma1,
                 lower =  c(-3, .1, 0), upper = c(3, 2, .7))
-\dontrun{
   res16 <- bayes(formula = ~ c + (1-c)/(1 + exp(-b *(x - a))), predvars = "x",
                  parvars = c("a", "b", "c"),
                  family = binomial(), lx = -3, ux = 3,
                  k =  4, iter = 500, prior = norm5,
                  ICA.control = list(rseed = 1366, ncount = 50),
                  crt.bayes.control = list(cubature = list(maxEval = 2500, tol = 1e-4)))
-  plot(res16, sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4),
-                                        optslist = list(maxeval = 3000)))
+  plot(res16,
+       sens.bayes.control = list(cubature = list(maxEval = 3000, tol = 1e-4)),
+       sens.control = list(optslist = list(maxeval = 3000)))
   # took 925 second on my system
 }
 
